﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Epi_Flex.Core.Types;
using System.Collections.ObjectModel;
using Infragistics.Controls.Schedules;
using System.Windows.Media;
using Infragistics;

namespace EpiFlexDispatcherMockup
{
    public class ViewModel : BaseInfo
    {
        ListScheduleDataConnector MyListScheduleDataConnector;
        public XamScheduleDataManager MyXamScheduleDataManager;

        ObservableCollection<Resource> AllResources;
        ObservableCollection<ResourceCalendar> AllCalendars;
        ObservableCollection<EpiFlexAppointment> AllAppointments;
        public CalendarGroup DefaultCalendarGroup;
        
        public ViewModel()
        {
            AllResources = new ObservableCollection<Resource>();
            AllCalendars = new ObservableCollection<ResourceCalendar>();
            AllAppointments = new ObservableCollection<EpiFlexAppointment>();
            DefaultCalendarGroup = new CalendarGroup();

            MyListScheduleDataConnector = new ListScheduleDataConnector();
            MyListScheduleDataConnector.ResourceItemsSource = AllResources;
            MyListScheduleDataConnector.ResourceCalendarItemsSource = AllCalendars;
            MyListScheduleDataConnector.AppointmentItemsSource = AllAppointments;
            //MyListScheduleDataConnector.ResourcePropertyMappings = new ResourcePropertyMappingCollection() { UseDefaultMappings = true };
            //MyListScheduleDataConnector.ResourceCalendarPropertyMappings = new ResourceCalendarPropertyMappingCollection() { UseDefaultMappings = true };

            #region ThisDoesn'tWork
                //MyListScheduleDataConnector.AppointmentPropertyMappings = new AppointmentPropertyMappingCollection();
                //MyListScheduleDataConnector.AppointmentPropertyMappings.UseDefaultMappings = true;
            #endregion //ThisDoesn'tWork

            #region ThisDoesWork
                MyListScheduleDataConnector.AppointmentPropertyMappings = new AppointmentPropertyMappingCollection();
                MyListScheduleDataConnector.AppointmentPropertyMappings.Add(AppointmentProperty.Id, "Id");
                MyListScheduleDataConnector.AppointmentPropertyMappings.Add(AppointmentProperty.Start, "Start");
                MyListScheduleDataConnector.AppointmentPropertyMappings.Add(AppointmentProperty.End, "End");
                MyListScheduleDataConnector.AppointmentPropertyMappings.Add(AppointmentProperty.OwningResourceId, "OwningResourceId");
                MyListScheduleDataConnector.AppointmentPropertyMappings.Add(AppointmentProperty.OwningCalendarId, "OwningCalendarId");
                MyListScheduleDataConnector.AppointmentPropertyMappings.Add(AppointmentProperty.Subject, "Subject");
                MyListScheduleDataConnector.AppointmentPropertyMappings.Add(AppointmentProperty.Description, "Description");
                MyListScheduleDataConnector.AppointmentPropertyMappings.Add(AppointmentProperty.IsTimeZoneNeutral, "IsTimeZoneNeutral");
            #endregion //ThisDoesWork


            MyXamScheduleDataManager = new XamScheduleDataManager();
            MyXamScheduleDataManager.DataConnector = MyListScheduleDataConnector;

            TimeRange MyWorkingHours = new TimeRange(TimeSpan.Parse("07:00:00"), TimeSpan.Parse("17:00:00"));
            MyXamScheduleDataManager.Settings = new ScheduleSettings();
            MyXamScheduleDataManager.Settings.WorkingHours = new Infragistics.Controls.Schedules.WorkingHoursCollection(MyWorkingHours);


            MyXamScheduleDataManager.CalendarGroups.Add(DefaultCalendarGroup);
            
            Resource NewResource = new Resource() { Id = "DispatcherId", Name = "My" };
            AllResources.Add(NewResource);

            MyXamScheduleDataManager.CurrentUser = NewResource;

            for (Int32 X = 0; X < 6; X++)
            {
                ResourceCalendar NewCalendar = new ResourceCalendar();
                NewCalendar.Id = "Tech" + X + "IdCalendar";
                NewCalendar.Name = "Tech " + X;
                NewCalendar.IsVisible = true;
                NewCalendar.OwningResourceId = NewResource.Id;
                NewCalendar.BaseColor = (Color)ColorConverter.ConvertFromString("#a6c0e0");
                for (int i = 0; i < 11; i++)
                {
                    EpiFlexAppointment NewAppt = new EpiFlexAppointment();
                    NewAppt.Id = Guid.NewGuid().ToString();
                    NewAppt.Subject = NewCalendar.Name.ToString() + " Service Call " + i;
                    NewAppt.OwningCalendarId = NewCalendar.Id;
                    NewAppt.OwningResourceId = NewResource.Id;
                    NewAppt.IsTimeZoneNeutral = true;
                    NewAppt.Start = DateTime.Now.Date + DateTime.Parse("8:00:00").AddMinutes(i * 15).TimeOfDay;
                    NewAppt.End = NewAppt.Start.AddMinutes(15);

                    AllAppointments.Add(NewAppt);
                }
                AllCalendars.Add(NewCalendar);
            }

            foreach (ResourceCalendar ThisCal in NewResource.Calendars)
            {
                if (ThisCal != NewResource.PrimaryCalendar)
                {
                    DefaultCalendarGroup.Calendars.Add(ThisCal);
                }
            }
            //DefaultCalendarGroup.InitialCalendarIds = DefaultCalendarGroup.InitialCalendarIds.Remove(DefaultCalendarGroup.InitialCalendarIds.LastIndexOf(","));
            //MyXamScheduleDataManager.CurrentUser = AllResources[0];
            
        }
    }
}
